<?php
/*
 * Plugin Name: Extra Options - FavIcons
 * Description: Allows you to upload and set fav icons for the dashboard and the website.
 * Version: 1.1.0
 * Author: EdesaC
 * Author URI: http://webdev-tuts.com/
 * Plugin URI: https://wordpress.org/plugins/extra-options-favicons/
 */

class ExtraFavIconStep1 {
    protected $_plugin_url;
    protected $_plugin_folder;
    
    public function __construct($file) {        
        if (!$file) {
            throw new Error('Missing 1 argument!');
        }
        
        $this->_plugin_url = plugin_dir_url($file);
        $this->_plugin_folder = basename(dirname($file));
        
        register_activation_hook(__FILE__, array($this, 'pluginActivate'));
        register_deactivation_hook(__FILE__, array($this, 'pluginDeactivate'));
        
        add_action('admin_menu', array($this, 'registerExtraOptMenu'));
        add_action('wp_head', array($this, 'loadWebsiteFavicon'));
        add_action('admin_head', array($this, 'loadAdminFavicon'));        
        add_action('admin_enqueue_scripts', array($this, 'loadAdminScriptsCss')); 
    }

    /**
     * This function is executed everytime the plugin is activated
     * @activation_hook
     */
    public function pluginActivate() {
        $options = get_option('extra-options-sub-menus');
        $info = array('label' => 'Favicons', 'desc' => 'set the favicons - admin and front end', 'link' => '?page=extra-options-favicons');
        $options['favicons'] = $info;
        update_option('extra-options-sub-menus', $options);
    }

    /**
     * This function is executed everytime the plugin is deactivated
     * @deactivation_hook
     */    
    public function pluginDeactivate() {
        $options = get_option('extra-options-sub-menus');
        unset($options['favicons']);
        update_option('extra-options-sub-menus', $options);
    }

    public function registerExtraOptMenu() {
        global $menu;
        $menuExist = false;

        foreach ($menu as $item) {
            if (strtolower($item[0]) == strtolower('Extra Options')) {
                $menuExist = true;
            }
        }

        if (!$menuExist) {
            add_menu_page('Extra Options', 'Extra Options', 'administrator', 'extra-options', array($this, 'showExtraOptionsPage'));
        }
        add_submenu_page('extra-options', 'Favicons', 'Favicons', 'administrator', 'extra-options-favicons', array($this, 'showSettingsPage'));
    }

    /**
     * Shows the Extra Options submenu
     * @menu_page extra-options
     */
    public function showExtraOptionsPage() {
        $options = get_option('extra-options-sub-menus');
        ?>
        <div class="wrap">
            <h1>Extra Options</h1>
            <br />
            <table class="wp-list-table widefat fixed striped posts">
                <tbody id="extra-plugins-list">
        <?php foreach ($options as $idx => $data) { ?>
                        <tr>
                            <td style="width: 25%"><strong><a href="?page=extra-options-woocommerce"><?php echo $data['label'] ?></a></strong></td>
                            <td style="width: 55%"><?php echo $data['desc'] ?></td>
                            <td style="width: 20%"><a class="button" href="<?php echo $data['link'] ?>">Customize</a></td>
                        </tr>
        <?php } ?>
                </tbody>
            </table>            
        </div>
        <?php
    }
    
    /**
     * Shows the Favicons settings page
     * @submenu_page extra-options-favicons
     */
    public function showSettingsPage() {
        ?>
        <div class="wrap od-wrapper">    
            <h1>Extra Options &raquo; Favicons</h1>
            <div id="left-pane">            
                <?php $this->showSettingsForm() ?>
            </div>
            <div id="right-pane">
                <div id="help">
                    <h4>Click <a href="https://wordpress.org/plugins/extra-options-favicons/" target="_blank">here</a> to learn how to use the plugin.</h4>
                    <p>You may also create a ticket regarding your concern <a href="https://wordpress.org/support/plugin/extra-options-favicons" target="_blank"><strong>here</strong></a>.</p>                    
                </div>
            </div>
        </div>
        <?php
    }

    /**
     * Shows the Favicons settings form
     */
    public function showSettingsForm() {
        $r = get_option("extra-favicon");
        $current_web_icon = $r['website-favicon'];
        $current_admin_icon = $r['admin-favicon'];

        if (isset($_POST['sub_favico']) && $_POST['sub_favico'] == 1) {
            $w_ico = sanitize_text_field($_POST['website-favicon']);
            $a_ico = sanitize_text_field($_POST['admin-favicon']);

            $w_ext = pathinfo($w_ico, PATHINFO_EXTENSION);
            $a_ext = pathinfo($a_ico, PATHINFO_EXTENSION);

            $error1 = (!in_array($w_ext, array('ico', 'png', 'jpg', 'gif'))) ? true : false;
            $error2 = (!in_array($a_ext, array('ico', 'png', 'jpg', 'gif'))) ? true : false;

            if (($error1 && $w_ico != '') || ($error2 && $a_ico != '')) {
                $msg = 'Changes not saved. The file you uploaded is invalid.';
                $msg_type = 'error';
                $current_web_icon = $r['website-favicon'];
                $current_admin_icon = $r['admin-favicon'];
                $r = $_POST;
            } else {
                $newvalue['admin-favicon'] = $a_ico;
                $newvalue['website-favicon'] = $w_ico;

                $newvalue['enable-admin-icon'] = ($_POST['enable-admin-icon'] == 'on') ? 'on' : 'off';
                $newvalue['enable-website-icon'] = ($_POST['enable-website-icon'] == 'on') ? 'on' : 'off';
                $msg = 'Successfully updated dashboard and website favicons. <a href="?page=extra-options-favicons">Refresh</a> the browser for the changes to take effect!';
                $msg_type = 'success';
                update_option("extra-favicon", $newvalue);
                $r = get_option("extra-favicon");
                $current_web_icon = $r['website-favicon'];
                $current_admin_icon = $r['admin-favicon'];
            }

            echo '<div class="updated ' . $msg_type . '">' . "\n"
            . '<p>'
            . '<strong>'
            . __($msg, 'race_diary')
            . '</strong>'
            . '</p>' . "\n"
            . '</div>' . "\n";
        }
        ?>
        <form name="frm-favico" id="frm-favico" action="" method="post" enctype="multipart/form-data">
            <div><h3>Website</h3></div>
            <div style="clear: both; margin-bottom: 5px">
                <label>Enable</label> <input title="Enable" type="checkbox" name="enable-website-icon" <?php echo ($r['enable-website-icon'] == 'on') ? 'checked="checked"' : "" ?> /> 
            </div>
            <div class="uploader">
                <input id="website-favicon" name="website-favicon" type="text" value="<?php echo $r['website-favicon'] ?>" />
                <input class="button fav-media-uploader" rel="website-favicon" type="button" value="Upload" />
            </div>
        <?php if ($current_web_icon && $this->iconExists($current_web_icon)) { ?>
                <img class="favico-preview" src="<?php echo $current_web_icon ?>" />
            <?php } ?>                
            <br /><br />
            <div style="border-top: dashed #bbb 1px;">
                <h3>Dashboard</h3>
            </div>
            <div style="clear: both; margin-bottom: 5px">
                <label>Enable</label> <input title="Enable" type="checkbox" name="enable-admin-icon" <?php echo ($r['enable-admin-icon'] == 'on') ? 'checked="checked"' : "" ?> /> 
            </div>
            <div class="uploader">
                <input id="admin-favicon" name="admin-favicon" type="text" value="<?php echo $r['admin-favicon'] ?>" />
                <input class="button fav-media-uploader" rel="admin-favicon" type="button" value="Upload" />
            </div>
        <?php if ($current_admin_icon && $this->iconExists($current_admin_icon)) { ?>
                <img class="favico-preview" src="<?php echo $current_admin_icon ?>" />
            <?php } ?>
            <input type="hidden" name="sub_favico" value="1"/>
            <div class="submit"><input type="submit" class="button-primary" value="Save"/></div>                
        </form>
        <?php
    }

    /**
     * @action admin_enqueue_scripts
     */
    public function loadAdminScriptsCss() {
        wp_enqueue_script('jquery');                
        wp_enqueue_script('jquery-ui-core');
        wp_enqueue_script($this->_plugin_folder . '-admin-scripts', $this->_plugin_url . 'scripts/admin-scripts.js');
        
        wp_enqueue_style('jquery-ui', $this->_plugin_url . '/styles/jquery-ui.css');        
        wp_enqueue_style($this->_plugin_folder . '-admin-styles', $this->_plugin_url . 'styles/admin-styles.css?t=' . time());              
        wp_enqueue_media();
    }    

    /**
     * Check if the url of the icon exists
     * @param type $icon_url the url of the icons
     * @return boolean
     */
    public function iconExists($icon_url) {
        $headers = get_headers($icon_url);
        return stripos($headers[0], "200 OK") ? true : false;
    }

    /**
     * @action admin_head
     */
    public function loadAdminFavicon() {
        $r = get_option("extra-favicon");
        if ($r['enable-admin-icon'] == 'on') {
            echo '<link rel="shortcut icon" type="image/x-icon" href="' . $r['admin-favicon'] . '">';
        }
    }

    /**
     * @action wp_head
     */
    public function loadWebsiteFavicon() {
        $r = get_option("extra-favicon");
        if ($r['enable-website-icon'] == 'on') {
            echo '<link rel="shortcut icon" type="image/x-icon" href="' . $r['website-favicon'] . '">';
        }
    }    
}

//end class

new ExtraFavIconStep1(__FILE__);
